==> xlniuxdata-vipgame-1.0.18-20150713.071534-2-sources.jar: com/xunlei/niux/data/vipgame/vo/mobilegameapkversion/MobileGameApk.java <==
package com.xunlei.niux.data.vipgame.vo.mobilegameapkversion;

import com.ferret.common.dao.annotation.Table;

@Table(tableName="mobileGameApk",pkFieldName="apkId")
public class MobileGameApk {	

	private Long apkId;
	private String gameId;
	private String apkUrl;
	private String path;
	private String apkName;
	private String packageTime;
	private String apkStatus;
	private String testRemark;
	private String testUser;
	private String testTime;
	private String submitTestRemark;
	private String muliPhotoUrl;
	private Integer packageType;
	
	public Integer getPackageType() {
		return packageType;
	}
	public void setPackageType(Integer packageType) {
		this.packageType = packageType;
	}
	public String getMuliPhotoUrl() {
		return muliPhotoUrl;
	}
	public void setMuliPhotoUrl(String muliPhotoUrl) {
		this.muliPhotoUrl = muliPhotoUrl;
	}
	public String getPath() {
		return path;
	}
	public void setPath(String path) {
		this.path = path;
	}
	public String getApkUrl() {
		return apkUrl;
	}
	public void setApkUrl(String apkUrl) {
		this.apkUrl = apkUrl;
	}
	public Long getApkId() {
		return apkId;
	}
	public void setApkId(Long apkId) {
		this.apkId = apkId;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getApkName() {
		return apkName;
	}
	public void setApkName(String apkName) {
		this.apkName = apkName;
	}
	public String getPackageTime() {
		return packageTime;
	}
	public void setPackageTime(String packageTime) {
		this.packageTime = packageTime;
	}
	public String getApkStatus() {
		return apkStatus;
	}
	public void setApkStatus(String apkStatus) {
		this.apkStatus = apkStatus;
	}
	public String getTestRemark() {
		return testRemark;
	}
	public void setTestRemark(String testRemark) {
		this.testRemark = testRemark;
	}
	public String getTestUser() {
		return testUser;
	}
	public void setTestUser(String testUser) {
		this.testUser = testUser;
	}
	public String getTestTime() {
		return testTime;
	}
	public void setTestTime(String testTime) {
		this.testTime = testTime;
	}
	public String getSubmitTestRemark() {
		return submitTestRemark;
	}
	public void setSubmitTestRemark(String submitTestRemark) {
		this.submitTestRemark = submitTestRemark;
	}
	
	
}

==> xlniuxdata-vipgame-1.0.54-20160322.080119-3-sources.jar: com/xunlei/niux/data/vipgame/vo/mobilegameapkversion/MobileGameApk.java <==
package com.xunlei.niux.data.vipgame.vo.mobilegameapkversion;

import com.ferret.common.dao.annotation.Table;

@Table(tableName="mobileGameApk",pkFieldName="apkId")
public class MobileGameApk {	

	private Long apkId;
	private String gameId;
	private String apkUrl;
	private String path;
	private String apkName;
	private String packageTime;
	private String apkStatus;
	private String testRemark;
	private String testUser;
	private String testTime;
	private String submitTestRemark;
	private String muliPhotoUrl;
	private Integer packageType;
	private Integer isWDJGame;
	
	public Integer getPackageType() {
		return packageType;
	}
	public void setPackageType(Integer packageType) {
		this.packageType = packageType;
	}
	public String getMuliPhotoUrl() {
		return muliPhotoUrl;
	}
	public void setMuliPhotoUrl(String muliPhotoUrl) {
		this.muliPhotoUrl = muliPhotoUrl;
	}
	public String getPath() {
		return path;
	}
	public void setPath(String path) {
		this.path = path;
	}
	public String getApkUrl() {
		return apkUrl;
	}
	public void setApkUrl(String apkUrl) {
		this.apkUrl = apkUrl;
	}
	public Long getApkId() {
		return apkId;
	}
	public void setApkId(Long apkId) {
		this.apkId = apkId;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getApkName() {
		return apkName;
	}
	public void setApkName(String apkName) {
		this.apkName = apkName;
	}
	public String getPackageTime() {
		return packageTime;
	}
	public void setPackageTime(String packageTime) {
		this.packageTime = packageTime;
	}
	public String getApkStatus() {
		return apkStatus;
	}
	public void setApkStatus(String apkStatus) {
		this.apkStatus = apkStatus;
	}
	public String getTestRemark() {
		return testRemark;
	}
	public void setTestRemark(String testRemark) {
		this.testRemark = testRemark;
	}
	public String getTestUser() {
		return testUser;
	}
	public void setTestUser(String testUser) {
		this.testUser = testUser;
	}
	public String getTestTime() {
		return testTime;
	}
	public void setTestTime(String testTime) {
		this.testTime = testTime;
	}
	public String getSubmitTestRemark() {
		return submitTestRemark;
	}
	public void setSubmitTestRemark(String submitTestRemark) {
		this.submitTestRemark = submitTestRemark;
	}

	public Integer getIsWDJGame() {
		return isWDJGame;
	}

	public void setIsWDJGame(Integer isWDJGame) {
		this.isWDJGame = isWDJGame;
	}
}
